@@ -4,7 +4,7 @@ package Acme::ReturnValue;
 use 5.010;
 use strict;
 use warnings;
-our $VERSION = '1.002';
+our $VERSION = '1.003';
 
 # ABSTRACT: report interesting return values
 
@@ -232,7 +232,7 @@ sub in_file {
     }
 }
 
-"let's return a strange value";
+"let's return a strange value from Riga";
 
 __END__
 
@@ -246,7 +246,7 @@ Acme::ReturnValue - report interesting return values
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 SYNOPSIS
 
